@@ -14,20 +14,21 @@ sub _init {
     $self->set_suggestion_box( new Yote::Obj() );
     $self->set_yote_blog( new Yote::RootObj() );
     $self->set_sandbox( new Yote::Obj() );
+    $self->set_rolodex( new Yote::Obj() );
     $self->set_page( new Yote::RootObj() );
     $self->SUPER::_init();
 }
-sub _load {
-    my $self = shift;
-    $self->get_sandbox( new Yote::Obj() );
-    $self->get_rolodex( new Yote::Obj() );
-    $self->get_page( new Yote::RootObj() );
-}
+
 sub reset_sandbox {
     my $self = shift;
     $self->set_sandbox( new Yote::Obj() );
 }
 
+sub precache {
+    my( $self, $data, $account ) = @_;
+    return [ $self->get_chat(), $self->get_suggestion_box(), $self->get_yote_blog(), 
+	     $self->get_sandbox(), $self->get_page()->get_todos(), $self->get_page(), $self->get_page()->get_todos(), @{ $self->get_page()->get_todos() || [] }, $self->get_rolodex() ];
+} #_precache
 
 1;
 
